# Community Code of Conduct

CreditRiskEngine follows the [FINOS Community Code of Conduct](https://www.finos.org/code-of-conduct).

If you encounter conduct issues, please report them following the procedures
outlined in the FINOS Code of Conduct.
